# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}

# Qt imports
from qtpy.QtCore import QSize, Signal, Slot
from qtpy.QtWidgets import QLabel, QVBoxLayout, QGroupBox, QMessageBox


# Local imports
from pyllo.ui.plugin import PluginMainWidget
from ..api import {{cookiecutter.plugin_class_name}}Actions



class {{cookiecutter.plugin_class_name}}Widget(PluginMainWidget):
    """
    Main widget for {{cookiecutter.plugin_class_name|lower}}
    
    TODO: add description here.
    """

    # --- Signals
    # ----------------------------------------------
    sigTest = Signal()

    # --- PluginMainWidget API
    # ----------------------------------------------
    def setup(self):
        # Widgets
        self.label = QLabel("{{cookiecutter.plugin_class_name|lower}} widget label.")

        # Widgets
        self.label = QLabel("{{cookiecutter.plugin_class_name|lower}} plugin dockable window widget label.")
        self.gb = QGroupBox("{{cookiecutter.plugin_class_name|lower}} plugin")

        # Layouts
        gbLayout = QVBoxLayout()
        gbLayout.addWidget(self.label)
        self.gb.setLayout(gbLayout)

        layout = QVBoxLayout()
        layout.addWidget(self.gb)
        self.setLayout(layout)

        # TODO: setup actions here.
        self.testAction = self.createAction(
            {{cookiecutter.plugin_class_name}}Actions.Test,
            text='Test',
            tip='Test',
            icon=self.createIcon('test'),
            triggered=self.test
        )

    def getTitle(self):
        return "{{cookiecutter.plugin_class_name|lower}}"

    def updateActions(self):
        # update actions
        ...

    def test(self):
        QMessageBox.information(self,
                                self.getName(),
                                "[{{cookiecutter.plugin_class_name}}]: Test action for demo.",
                                QMessageBox.Ok)




# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}


# ---- Constants
# ------------------------------------------------------
class {{cookiecutter.plugin_class_name}}Actions:
    # Declare plugin actions here
    Test = "test_action"




# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}

# Python imports

# Qt imports
from qtpy.QtWidgets import (QButtonGroup, QGroupBox, QHBoxLayout, QLabel,
                            QVBoxLayout)

# Local imports
from pyllo.core.runtime.environ import getCwdOrHome
from pyllo.ui.preferences import PluginConfigPage


class {{cookiecutter.plugin_class_name}}ConfigPage(PluginConfigPage):
    """
    {{cookiecutter.plugin_class_name|lower}} configuration page.
    """
    def setupPage(self):
        aboutLabel = QLabel("This <b>{{cookiecutter.plugin_class_name|lower}} plugin</b> is "
                            "auto-generated. You should customize it to fit your needs.")
                
        aboutLabel.setWordWrap(True)
        

        testGroup = QGroupBox("First Group")
        testBg = QButtonGroup(testGroup)
        testLabel = QLabel("Test label:")
        testLabel.setWordWrap(True)

        firstRadio = self.createRadiobutton(
            "The first radio button",
            option="test/first",
            default=True,
            tip="First selection",
            buttonGroup=testBg
        )

        secondRadio = self.createRadiobutton(
            "The second radio button",
            option="test/second",
            default=False,
            tip="Second selection",
            buttonGroup=testBg
        )

        dirBd = self.createBrowseDir("",
                                    'test/test_directory',
                                    getCwdOrHome())

        vbox1 = QVBoxLayout()

        hbox1 = QHBoxLayout()
        hbox1.addWidget(secondRadio)
        hbox1.addWidget(dirBd)
        
        vbox1.addWidget(testLabel)
        vbox1.addWidget(firstRadio)
        vbox1.addLayout(hbox1)
        testGroup.setLayout(vbox1)

        vbox2 = QVBoxLayout()
        vbox2.addWidget(aboutLabel)
        vbox2.addSpacing(10)
        vbox2.addWidget(testGroup)
        vbox2.addStretch(1)
        self.setLayout(vbox2)




# -*- coding: utf-8 -*-
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}

import sys
import os
import os.path as osp
from setuptools import find_packages, setup
#
# =============================================================================
# Minimal Python version sanity check
# Taken from the notebook setup.py -- Modified BSD License
# =============================================================================
v = sys.version_info
if v[0] >= 3 and v[:2] < (3, 6):
    error = "ERROR: Pyllo requires Python version 3.6 and above."
    print(error, file=sys.stderr)
    sys.exit(1)

# =============================================================================
# Auxiliary functions
# =============================================================================
def get_package_data(name, extlist):
    """
    Return data files for package *name* with extensions in *extlist*.
    """
    flist = []
    # Workaround to replace os.path.relpath (not available until Python 2.6):
    offset = len(name)+len(os.pathsep)
    for dirpath, _dirnames, filenames in os.walk(name):
        if 'tests' not in dirpath:
            for fname in filenames:
                if (not fname.startswith('.') and
                        osp.splitext(fname)[1] in extlist):
                    flist.append(osp.join(dirpath, fname)[offset:])
    return flist


# =============================================================================
# Files added to the package
# =============================================================================
EXTLIST = ['.pyd', '.pot', '.po', '.mo', '.svg', '.png', '.css', '.html', '.js',
           '.ini', '.txt', '.qss', '.ttf', '.json', '.rst', '.bloom',
           '.ico', '.gif', '.mp3', '.ogg', '.sfd', '.bat', '.sh']


install_requires = [
    "pyllo==1.0.0.dev0",
]

if sys.platform == "darwin":
    install_requires += [
        'applaunchservices==0.3.0'
    ]


setup(
    name='{{cookiecutter.project_name}}',
    version='0.0.0.dev0',
    packages=find_packages(),
    package_data={
        '{{cookiecutter.project_name}}': get_package_data('{{cookiecutter.project_name}}', EXTLIST)
    },
    entry_points={
        'pyllo.plugins': [
            f'{{cookiecutter.plugin_class_name|lower}} = {{cookiecutter.project_name}}.plugin:{{cookiecutter.plugin_class_name}}'
        ]
    },
    # include_package_data=True,
    author="{{cookiecutter.author}}",
    author_email="",
    description="{{cookiecutter.plugin_description}}",
    keywords="",
    url="",   # project home page
    project_urls={
    },
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development :: Interpreters",
    ],
    install_requires=install_requires,
)



#!/usr/bin/env python
import os.path as osp
import sys
import subprocess
from rich import print
from cookiecutter.main import cookiecutter

logo = r"""
 ________  ___    ___ ___       ___       ________     
|\   __  \|\  \  /  /|\  \     |\  \     |\   __  \     
\ \  \|\  \ \  \/  / | \  \    \ \  \    \ \  \|\  \    
 \ \   ____\ \    / / \ \  \    \ \  \    \ \  \\\  \   
  \ \  \___|\/  /  /   \ \  \____\ \  \____\ \  \\\  \  
   \ \__\ __/  / /      \ \_______\ \_______\ \_______\
    \|__||\___/ /        \|_______|\|_______|\|_______|
         \|___|/     
        ╭──────────────────────────╮
        │   Welcome to the Pyllo   │
        │   Plugin Generator!      │
        ╰──────────────────────────╯
        
"""

HERE = osp.abspath(osp.dirname(__file__))

def query_yes_no(question, default="yes"):
    """Ask a yes/no question via raw_input() and return their answer.

    "question" is a string that is presented to the user.
    "default" is the presumed answer if the user just hits <Enter>.
        It must be "yes" (the default), "no" or None (meaning
        an answer is required of the user).

    The "answer" return value is one of "yes" or "no".
    """
    valid = {"yes": "yes", "y": "yes", "ye": "yes",
             "no": "no", "n": "no"}
    if default is None:
        prompt = " [y/n] "
    elif default == "yes":
        prompt = " [Y/n] "
    elif default == "no":
        prompt = " [y/N] "
    else:
        raise ValueError("invalid default answer: '%s'" % default)

    while 1:
        print(question + prompt)
        print("> ", end="")
        choice = input().lower()
        if default is not None and choice == '':
            return default
        elif choice in valid.keys():
            return valid[choice]
        else:
            print("Please respond with 'yes' or 'no' "
                  "(or 'y' or 'n').\n")
            

def select_pick(title: str, options=[], default=None):
    while 1:
        print(f"{title} [1-{len(options)}]")
        for i, option in enumerate(options):
            print(f"{i+1}) {option}")
        
        print("> ", end="")
        choice = input().lower()
        if default is not None and choice == '':
            return default
        else:
            try:
                num = int(choice)
                if num < 1 or num > len(options):
                    raise IndexError
                return num - 1
            except Exception:
                print(f"Please respond with number in [1-{len(options)}].\n")



def main():
    # ----- start of main -----
    print(logo)
    title = '[bold]? What type of plugin do you want to create?[bold/]'
    options = ['New Container Plugin',
               'New Dockable Plugin',
               'New Language Support',
               'New Custom Editor',
               'New Code Editor Extension']
    index = select_pick(title, options, 1)
    if index == 0:
        result = cookiecutter(HERE, directory="plugin")
    elif index == 1:
        result = cookiecutter(HERE, directory="dockableplugin")

    if index in (0, 1):
        choice = query_yes_no("? Do you want to open project in Pyllo now? (Pyllo is needed)")
        if choice == "yes":
            subprocess.Popen(f"pyllo {result}",
                             shell=True,
                             start_new_session=True,
                             stdout=subprocess.DEVNULL,
                             stderr=subprocess.STDOUT)



if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}

# Third-party imports
from qtpy.QtCore import Signal

# Local imports
from pyllo import Plugins
from pyllo.core.runtime.spi import PylloPlugin, onPluginAvailable
from pyllo.plugins.toolbar.api import ApplicationToolbars, MainToolbarSections
from .container import {{cookiecutter.plugin_class_name}}Container
from .confpage import {{cookiecutter.plugin_class_name}}ConfigPage

class {{cookiecutter.plugin_class_name}}(PylloPlugin):
    """
    {{cookiecutter.plugin_class_name|lower}} plugin.
    {{cookiecutter.plugin_description}} 
    """

    NAME = "{{cookiecutter.plugin_class_name|lower}}"
    # You can add plugins that this plugin requires. (Pyllo assures you have these)
    REQUIRES = [Plugins.Application, Plugins.Preferences, Plugins.Toolbar, Plugins.MainMenu]
    # You can add plugins that this plugin requires optionally.
    OPTIONAL = []

    CONTAINER_CLASS = {{cookiecutter.plugin_class_name}}Container
    CONF_SECTION = NAME
    CONF_WIDGET_CLASS = {{cookiecutter.plugin_class_name}}ConfigPage
    CONF_FILE = False

    # ---- Signals
    # -----------------------------------------------------
    sigTest = Signal()

    # ---- PylloPlugin API
    # -----------------------------------------------------
    def getName(self):
        return "{{cookiecutter.plugin_class_name|lower}}"

    @staticmethod
    def getDescription():
        return "{{cookiecutter.plugin_description}}"

    def getIcon(self):
        return self.createIcon("testPluginIcon")

    def onInitialize(self):
        # Initialize this plugin.
        # Caution:
        # Within this method you should avoid getting other plugins
        # (because they may not be ready), if certain features
        # depend on other plugins, and information of theirs can
        # not be known after their initialization. You must use
        # :meth:`onIntegrate` which called after all of plugins
        # have been self-initialized.
        container: {{cookiecutter.plugin_class_name}}Container
        container = self.getContainer()
        # TODO: add initialization process here

    def onTearDown(self, cancelable=False):
        # Before plugin been teared down.
        # TODO: add teardown process here
        ...

    @onPluginAvailable(plugin=Plugins.Toolbar)
    def onToolbarAvailable(self):
        toolbar = self.getPlugin(Plugins.Toolbar)
        toolbar.addItemToApplicationToolbar(
            self.getContainer().testAction, ApplicationToolbars.Main,
            MainToolbarSections.ApplicationSection
        )
        # TODO: add plugin actions to toolbar here
        ...

    @onPluginAvailable(plugin=Plugins.MainMenu)
    def onMainMenuAvailable(self):
        mainmenu = self.getPlugin(Plugins.MainMenu)
        # TODO: add mainmenu actions or submenus here
        ...

    @onPluginAvailable(plugin=Plugins.Preferences)
    def onPreferencesAvailable(self):
        preferences = self.getPlugin(Plugins.Preferences)
        preferences.registerPluginPreferences(self)


 


# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}

"""
{{cookiecutter.plugin_class_name}} widget.
"""

# Third party imports
from qtpy.QtCore import QSize, Signal, Slot
from qtpy.QtWidgets import QMessageBox

# Local imports
from pyllo.ui.plugin import PluginMainContainer
from .api import {{cookiecutter.plugin_class_name}}Actions


class {{cookiecutter.plugin_class_name}}Container(PluginMainContainer):
    """
    Container for {{cookiecutter.plugin_class_name|lower}}.
    
    TODO: add description here.
    """

    # Declare signals here
    sigTest = Signal()

    # ---- PluginMainContainer API
    # -----------------------------------------------
    def setup(self):
        
        #TODO: setup actions here.
        self.testAction = self.createAction(
            {{cookiecutter.plugin_class_name}}Actions.Test,
            text='Test',
            tip='Test',
            icon=self.createIcon('test'),
            triggered=self.test
        )

    def updateActions(self):
        # update actions
        ...

    def test(self):
        QMessageBox.information(self,
                                self.getName(),
                                "[{{cookiecutter.plugin_class_name}}]: Test action for demo.",
                                QMessageBox.Ok)



# -*- coding: utf-8 -*-
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}


def install(package):
    import subprocess
    import sys
    subprocess.check_call([sys.executable, "-m", "pip", "install", "-e", package])


if __name__ == "__main__":
    install(".")
    from pyllo.main import main
    main()



# -*- coding: utf-8 -*-
# Copyright © Connet Information Technology Company, Shanghai.

from setuptools import find_packages, setup
import sys
import os
import os.path as osp

# =============================================================================
# Minimal Python version sanity check
# Taken from the notebook setup.py -- Modified BSD License
# =============================================================================
v = sys.version_info
if v[0] >= 3 and v[:2] < (3, 6):
    error = "ERROR: Pyllo requires Python version 3.6 and above."
    print(error, file=sys.stderr)
    sys.exit(1)


# =============================================================================
# Constants
# =============================================================================
NAME = 'pyllo-kickstart'
LIBNAME = 'pyllo_kickstart'
HERE = os.path.abspath(os.path.dirname(__file__))

# =============================================================================
# Auxiliary functions
# =============================================================================
def get_package_data(name, extlist):
    """
    Return data files for package *name* with extensions in *extlist*.
    """
    flist = []
    # Workaround to replace os.path.relpath (not available until Python 2.6):
    offset = len(name)+len(os.pathsep)
    for dirpath, _dirnames, filenames in os.walk(name):
        if 'tests' not in dirpath:
            for fname in filenames:
                if (not fname.startswith('.') and
                        osp.splitext(fname)[1] in extlist):
                    flist.append(osp.join(dirpath, fname)[offset:])
    return flist

def get_description():
    """Get long description."""
    with open(os.path.join(HERE, 'README.md'), 'r') as f:
        data = f.read()
    return data



# =============================================================================
# Files added to the package
# =============================================================================
EXTLIST = ['.json', '.py']


install_requires = [
    "pyllo>=1.0.0.dev0",
    "rich==13.3.5"
]

if sys.platform == "darwin":
    install_requires += [
        'applaunchservices==0.3.0'
    ]


setup(
    name=NAME,
    version="1.0.2",
    packages=find_packages(),
    package_data={LIBNAME: get_package_data(LIBNAME, EXTLIST)},
    entry_points={
        'console_scripts': [
            'pyllo-kickstart=pyllo_kickstart.main:main',
        ]
    },
    author="Shanghai Connet Information Technology Company Ltd.",
    author_email="tech_support@shconnet.com.cn",
    description="Pyllo plugin generator",
    long_description=get_description(),
    long_description_content_type='text/markdown',
    keywords="pyllo plugin template generator",
    url="",   # project home page
    project_urls={
    },
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Topic :: Software Development :: Interpreters",
    ],
    install_requires=install_requires,
)
